Computes honest out-of-sample predictions for an morf.forest object.
honest_predictions(
forest,
honest_sample,
test_sample,
y_m_honest,
y_m_1_honest
)Out-of-sample honest predictions.
morf.forest object.
Honest sample.
Test sample.
Indicator variable, whether the outcome is smaller than or equal to the m-th class.
Indicator variable, whether the outcome is smaller than or equal to the (m-1)-th class.
honest_predictions replaces the leaf estimates of forest using the outcome from the associated
honest sample (using the prediction method of morf). The honest sample must not have been used
to build the trees.